# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agatha_protobuf/analysis/analysis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'agatha_protobuf/analysis/analysis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'agatha_protobuf/analysis/analysis.proto\x12\x08\x61nalysis\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\"b\n\x15\x43reateAnalysisRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x12\n\x05model\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_model\"\x9b\x01\n\x08\x41nalysis\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\r\n\x05model\x18\x04 \x01(\t\x12\x10\n\x08response\x18\x05 \x01(\t\x12\r\n\x05score\x18\x06 \x01(\t\x12\x0c\n\x04text\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\x12\x0c\n\x04user\x18\t \x01(\t\" \n\x12GetAnalysisRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x9d\x01\n\x13ListAnalysesRequest\x12\x12\n\x05model\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04user\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x08\n\x06_modelB\x07\n\x05_userB\x0c\n\n_page_sizeB\r\n\x0b_page_token\"U\n\x14ListAnalysesResponse\x12$\n\x08\x61nalyses\x18\x01 \x03(\x0b\x32\x12.analysis.Analysis\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\x15UpdateAnalysisRequest\x12$\n\x08\x61nalysis\x18\x01 \x01(\x0b\x32\x12.analysis.Analysis\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"#\n\x15\x44\x65leteAnalysisRequest\x12\n\n\x02id\x18\x01 \x01(\t\"$\n\x16\x44\x65leteAnalysisResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\xad\x01\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x61nalyze\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\t\x12\r\n\x05model\x18\x05 \x01(\t\x12\x10\n\x08response\x18\x06 \x01(\t\x12\r\n\x05score\x18\x07 \x01(\t\x12\x0c\n\x04text\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\x12\x0c\n\x04user\x18\n \x01(\t\"\xa1\x01\n\x15\x43reateFeedbackRequest\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\r\n\x05scale\x18\x02 \x01(\t\x12\x0f\n\x07\x61nalyze\x18\x03 \x01(\t\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\t\x12\r\n\x05input\x18\x05 \x01(\t\x12\x12\n\x05\x62uild\x18\x06 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05model\x18\x07 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_buildB\x08\n\x06_model\" \n\x12GetFeedbackRequest\x12\n\n\x02id\x18\x01 \x01(\t\"u\n\x14ListFeedbacksRequest\x12\x0f\n\x07\x61nalyze\x18\x01 \x01(\t\x12\x16\n\tpage_size\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x17\n\npage_token\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"W\n\x15ListFeedbacksResponse\x12%\n\tfeedbacks\x18\x01 \x03(\x0b\x32\x12.analysis.Feedback\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\x15UpdateFeedbackRequest\x12$\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x01 \x01(\x0b\x32\x12.analysis.Feedback\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"#\n\x15\x44\x65leteFeedbackRequest\x12\n\n\x02id\x18\x01 \x01(\t\"$\n\x16\x44\x65leteFeedbackResponse\x12\n\n\x02id\x18\x01 \x01(\t\"j\n\x1d\x43reateAnalysisFromLLMSRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\x12\x12\n\x05model\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_model\"=\n\x1e\x43reateAnalysisFromLLMSResponse\x12\x1b\n\x04llms\x18\x01 \x03(\x0b\x32\r.analysis.LLM\"P\n\x1aGetAnalysisFromLLMSRequest\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04user\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_user\":\n\x1bGetAnalysisFromLLMSResponse\x12\x1b\n\x04llms\x18\x01 \x03(\x0b\x32\r.analysis.LLM\"9\n\x03LLM\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x08\x61nalysis\x18\x02 \x01(\x0b\x32\x12.analysis.Analysis\"*\n\x17\x43reateMigrationResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"R\n\x18\x43reateMoodHistoryRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04mood\x18\x02 \x01(\t\x12\x11\n\x04note\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_note\"k\n\x0bMoodHistory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0c\n\x04mood\x18\x03 \x01(\t\x12\x0c\n\x04note\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\t\x12\x12\n\nupdated_at\x18\x06 \x01(\t\"\x9e\x01\n\x16ListMoodHistoryRequest\x12\x11\n\x04user\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04mood\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_userB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_mood\"a\n\x17ListMoodHistoryResponse\x12-\n\x0emood_histories\x18\x01 \x03(\x0b\x32\x15.analysis.MoodHistory\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x10ListMoodsRequest\x12\x15\n\x08\x63\x61tegory\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_category\"7\n\x03Tip\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\"\n\x05\x41sset\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x83\x02\n\x04Mood\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x1e\n\x05\x63over\x18\x03 \x01(\x0b\x32\x0f.analysis.Asset\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nidentifier\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12(\n\x08\x63\x61tegory\x18\x07 \x01(\x0b\x32\x16.analysis.MoodCategory\x12\r\n\x05order\x18\x08 \x01(\x05\x12\x12\n\ntext_color\x18\t \x01(\t\x12\x1b\n\x04tips\x18\n \x03(\x0b\x32\r.analysis.Tip\x12\x1e\n\x05video\x18\x0b \x01(\x0b\x32\x0f.analysis.Asset\"^\n\x0cMoodCategory\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12\r\n\x05order\x18\x04 \x01(\x05\x12\x10\n\x08platform\x18\x05 \x01(\t\"2\n\x11ListMoodsResponse\x12\x1d\n\x05moods\x18\x01 \x03(\x0b\x32\x0e.analysis.Mood\"\xec\x01\n\x11\x43reateMoodRequest\x12\r\n\x05\x63olor\x18\x01 \x01(\t\x12\x1e\n\x05\x63over\x18\x02 \x01(\x0b\x32\x0f.analysis.Asset\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nidentifier\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x06 \x01(\t\x12\r\n\x05order\x18\x07 \x01(\x05\x12\x12\n\ntext_color\x18\x08 \x01(\t\x12\x1b\n\x04tips\x18\t \x03(\x0b\x32\r.analysis.Tip\x12\x1e\n\x05video\x18\n \x01(\x0b\x32\x0f.analysis.Asset\"\xf8\x01\n\x11UpdateMoodRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12\x1e\n\x05\x63over\x18\x03 \x01(\x0b\x32\x0f.analysis.Asset\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nidentifier\x18\x05 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x07 \x01(\t\x12\r\n\x05order\x18\x08 \x01(\x05\x12\x12\n\ntext_color\x18\t \x01(\t\x12\x1b\n\x04tips\x18\n \x03(\x0b\x32\r.analysis.Tip\x12\x1e\n\x05video\x18\x0b \x01(\x0b\x32\x0f.analysis.Asset\"\x1c\n\x0eGetMoodRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x1f\n\x11\x44\x65leteMoodRequest\x12\n\n\x02id\x18\x01 \x01(\t\" \n\x12\x44\x65leteMoodResponse\x12\n\n\x02id\x18\x01 \x01(\t2\xfb\x0b\n\x0f\x41nalysisService\x12\x45\n\x0e\x43reateAnalysis\x12\x1f.analysis.CreateAnalysisRequest\x1a\x12.analysis.Analysis\x12?\n\x0bGetAnalysis\x12\x1c.analysis.GetAnalysisRequest\x1a\x12.analysis.Analysis\x12M\n\x0cListAnalyses\x12\x1d.analysis.ListAnalysesRequest\x1a\x1e.analysis.ListAnalysesResponse\x12\x45\n\x0eUpdateAnalysis\x12\x1f.analysis.UpdateAnalysisRequest\x1a\x12.analysis.Analysis\x12S\n\x0e\x44\x65leteAnalysis\x12\x1f.analysis.DeleteAnalysisRequest\x1a .analysis.DeleteAnalysisResponse\x12\x45\n\x0e\x43reateFeedback\x12\x1f.analysis.CreateFeedbackRequest\x1a\x12.analysis.Feedback\x12?\n\x0bGetFeedback\x12\x1c.analysis.GetFeedbackRequest\x1a\x12.analysis.Feedback\x12P\n\rListFeedbacks\x12\x1e.analysis.ListFeedbacksRequest\x1a\x1f.analysis.ListFeedbacksResponse\x12\x45\n\x0eUpdateFeedback\x12\x1f.analysis.UpdateFeedbackRequest\x1a\x12.analysis.Feedback\x12S\n\x0e\x44\x65leteFeedback\x12\x1f.analysis.DeleteFeedbackRequest\x1a .analysis.DeleteFeedbackResponse\x12k\n\x16\x43reateAnalysisFromLLMS\x12\'.analysis.CreateAnalysisFromLLMSRequest\x1a(.analysis.CreateAnalysisFromLLMSResponse\x12\x62\n\x13GetAnalysisFromLLMS\x12$.analysis.GetAnalysisFromLLMSRequest\x1a%.analysis.GetAnalysisFromLLMSResponse\x12L\n\x0f\x43reateMigration\x12\x16.google.protobuf.Empty\x1a!.analysis.CreateMigrationResponse\x12N\n\x11\x43reateMoodHistory\x12\".analysis.CreateMoodHistoryRequest\x1a\x15.analysis.MoodHistory\x12V\n\x0fListMoodHistory\x12 .analysis.ListMoodHistoryRequest\x1a!.analysis.ListMoodHistoryResponse\x12\x39\n\nCreateMood\x12\x1b.analysis.CreateMoodRequest\x1a\x0e.analysis.Mood\x12\x33\n\x07GetMood\x12\x18.analysis.GetMoodRequest\x1a\x0e.analysis.Mood\x12\x39\n\nUpdateMood\x12\x1b.analysis.UpdateMoodRequest\x1a\x0e.analysis.Mood\x12G\n\nDeleteMood\x12\x1b.analysis.DeleteMoodRequest\x1a\x1c.analysis.DeleteMoodResponse\x12\x44\n\tListMoods\x12\x1a.analysis.ListMoodsRequest\x1a\x1b.analysis.ListMoodsResponseBDZBgithub.com/BlueprintAI-org/protobuf/build/agatha_protobuf/analysisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agatha_protobuf.analysis.analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZBgithub.com/BlueprintAI-org/protobuf/build/agatha_protobuf/analysis'
  _globals['_CREATEANALYSISREQUEST']._serialized_start=116
  _globals['_CREATEANALYSISREQUEST']._serialized_end=214
  _globals['_ANALYSIS']._serialized_start=217
  _globals['_ANALYSIS']._serialized_end=372
  _globals['_GETANALYSISREQUEST']._serialized_start=374
  _globals['_GETANALYSISREQUEST']._serialized_end=406
  _globals['_LISTANALYSESREQUEST']._serialized_start=409
  _globals['_LISTANALYSESREQUEST']._serialized_end=566
  _globals['_LISTANALYSESRESPONSE']._serialized_start=568
  _globals['_LISTANALYSESRESPONSE']._serialized_end=653
  _globals['_UPDATEANALYSISREQUEST']._serialized_start=655
  _globals['_UPDATEANALYSISREQUEST']._serialized_end=765
  _globals['_DELETEANALYSISREQUEST']._serialized_start=767
  _globals['_DELETEANALYSISREQUEST']._serialized_end=802
  _globals['_DELETEANALYSISRESPONSE']._serialized_start=804
  _globals['_DELETEANALYSISRESPONSE']._serialized_end=840
  _globals['_FEEDBACK']._serialized_start=843
  _globals['_FEEDBACK']._serialized_end=1016
  _globals['_CREATEFEEDBACKREQUEST']._serialized_start=1019
  _globals['_CREATEFEEDBACKREQUEST']._serialized_end=1180
  _globals['_GETFEEDBACKREQUEST']._serialized_start=1182
  _globals['_GETFEEDBACKREQUEST']._serialized_end=1214
  _globals['_LISTFEEDBACKSREQUEST']._serialized_start=1216
  _globals['_LISTFEEDBACKSREQUEST']._serialized_end=1333
  _globals['_LISTFEEDBACKSRESPONSE']._serialized_start=1335
  _globals['_LISTFEEDBACKSRESPONSE']._serialized_end=1422
  _globals['_UPDATEFEEDBACKREQUEST']._serialized_start=1424
  _globals['_UPDATEFEEDBACKREQUEST']._serialized_end=1534
  _globals['_DELETEFEEDBACKREQUEST']._serialized_start=1536
  _globals['_DELETEFEEDBACKREQUEST']._serialized_end=1571
  _globals['_DELETEFEEDBACKRESPONSE']._serialized_start=1573
  _globals['_DELETEFEEDBACKRESPONSE']._serialized_end=1609
  _globals['_CREATEANALYSISFROMLLMSREQUEST']._serialized_start=1611
  _globals['_CREATEANALYSISFROMLLMSREQUEST']._serialized_end=1717
  _globals['_CREATEANALYSISFROMLLMSRESPONSE']._serialized_start=1719
  _globals['_CREATEANALYSISFROMLLMSRESPONSE']._serialized_end=1780
  _globals['_GETANALYSISFROMLLMSREQUEST']._serialized_start=1782
  _globals['_GETANALYSISFROMLLMSREQUEST']._serialized_end=1862
  _globals['_GETANALYSISFROMLLMSRESPONSE']._serialized_start=1864
  _globals['_GETANALYSISFROMLLMSRESPONSE']._serialized_end=1922
  _globals['_LLM']._serialized_start=1924
  _globals['_LLM']._serialized_end=1981
  _globals['_CREATEMIGRATIONRESPONSE']._serialized_start=1983
  _globals['_CREATEMIGRATIONRESPONSE']._serialized_end=2025
  _globals['_CREATEMOODHISTORYREQUEST']._serialized_start=2027
  _globals['_CREATEMOODHISTORYREQUEST']._serialized_end=2109
  _globals['_MOODHISTORY']._serialized_start=2111
  _globals['_MOODHISTORY']._serialized_end=2218
  _globals['_LISTMOODHISTORYREQUEST']._serialized_start=2221
  _globals['_LISTMOODHISTORYREQUEST']._serialized_end=2379
  _globals['_LISTMOODHISTORYRESPONSE']._serialized_start=2381
  _globals['_LISTMOODHISTORYRESPONSE']._serialized_end=2478
  _globals['_LISTMOODSREQUEST']._serialized_start=2480
  _globals['_LISTMOODSREQUEST']._serialized_end=2534
  _globals['_TIP']._serialized_start=2536
  _globals['_TIP']._serialized_end=2591
  _globals['_ASSET']._serialized_start=2593
  _globals['_ASSET']._serialized_end=2627
  _globals['_MOOD']._serialized_start=2630
  _globals['_MOOD']._serialized_end=2889
  _globals['_MOODCATEGORY']._serialized_start=2891
  _globals['_MOODCATEGORY']._serialized_end=2985
  _globals['_LISTMOODSRESPONSE']._serialized_start=2987
  _globals['_LISTMOODSRESPONSE']._serialized_end=3037
  _globals['_CREATEMOODREQUEST']._serialized_start=3040
  _globals['_CREATEMOODREQUEST']._serialized_end=3276
  _globals['_UPDATEMOODREQUEST']._serialized_start=3279
  _globals['_UPDATEMOODREQUEST']._serialized_end=3527
  _globals['_GETMOODREQUEST']._serialized_start=3529
  _globals['_GETMOODREQUEST']._serialized_end=3557
  _globals['_DELETEMOODREQUEST']._serialized_start=3559
  _globals['_DELETEMOODREQUEST']._serialized_end=3590
  _globals['_DELETEMOODRESPONSE']._serialized_start=3592
  _globals['_DELETEMOODRESPONSE']._serialized_end=3624
  _globals['_ANALYSISSERVICE']._serialized_start=3627
  _globals['_ANALYSISSERVICE']._serialized_end=5158
# @@protoc_insertion_point(module_scope)
